pub struct LoadedSkill {
pub file: SkillFile,
pub scope: SkillScope,
pub namespace: Option<String>,
}Expand description
Loaded skill with scope information.
Fields
file: SkillFileThe parsed skill file.
scope: SkillScopeScope level of the skill.
namespace: Option<String>For plugins, the plugin name prefix.
Implementations
Sourceimpl LoadedSkill
impl LoadedSkill
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Get the fully qualified name (with namespace if applicable).
Sourcepub fn effective_description(&self) -> String
pub fn effective_description(&self) -> String
Get the effective description.
Sourcepub fn is_model_invocable(&self) -> bool
pub fn is_model_invocable(&self) -> bool
Check if this skill can be invoked by the model.
Sourcepub fn is_user_invocable(&self) -> bool
pub fn is_user_invocable(&self) -> bool
Check if this skill can be invoked by the user.